* File: autoexec-vcd.sas - autoexec for VCD / v9;
* Updated 14 Jan 09 - streamlined for more general use;
* Updatad 16 Jan 09 - fixed path names for Win and Unix

/* --------------------------------------------------------------------
   Installation:
   1.  Set the macro variable sasvcd (below) for your system
   2.  Copy this file as autoexec.sas to where SAS can find it
       - (Windows) the root directory of your C:\ drive 
             copy autoexec-vcd.sas c:\autoexec.sas
           Alternatively:
            * copy to any directory on the Windows PATH
            * copy to the directory where SAS.EXE is found, e.g.,
              C:\Program Files\SAS\SASv9\SASFoundation\9.2 
            * Append the following to the Target field of the SAS icon
               -autoexec "drive:\path\to\autoexec-vcd.sas" 
       - (unix) your home directory 
             cp autoexec-vcd.sas ~/autoexec.sas

   If you already have an autoexec.sas file installed, you can either
   (a) Copy the lines below into it
   (b) Insert the following line in your existing autoexec.sas (modifying
       the 'path/to' part appropriately). 
       %include 'path/to/autoexec-vcd.sas';
 * --------------------------------------------------------------------- */

/* ---------------------------------------------------------------------
 *  Configuration: assign sasvcd to where you installed the VCD programs
     *** Include the trailing \ or / as appropriate for Windows or unix **
 * --------------------------------------------------------------------- */
%global sasvcd;
   *-- Windows: on a local drive;
%let sasvcd = c:\sasuser\Vcd\;
   *--  or can use a network drive;
*let sasvcd = \\ACADLABS\USR\COURSES\SASUSER\Vcd\;
   *--  for unix;
*let sasvcd = ~/sasuser/Vcd/;

options ls=80 ps=60;
options nostimer;

%*-- General goptions.sas file to set graphic options (shipped: empty);
filename goptions "&sasvcd\goptions.sas";

*-- Path name(s) for macros;
filename macros   (
              "&sasvcd.macros"
                  );


*-- Prepend my macro directories to SASAUTOS;
options mautosource;
options sasautos= (
                   "&sasvcd.macros",
                   SASAUTOS
                  );


*-- VCD directories: for %include catdata(...) etc. statements;;
filename catdata  "&sasvcd.catdata";
filename iml      "&sasvcd.iml";
filename sample   "&sasvcd.sample";
filename mosaics  "&sasvcd.mosaics";

*-- mosaic library (compiled IML routines);
/*
Change the line below to 
libname  mosaic   "&sasvcd.mosaics/v&ver-unix";
if runing on a unix system

*/
%let ver = %substr(&sysver,1,1); 
libname  mosaic   "&sasvcd.mosaics\v&ver"  access=readonly ;


options nofmterr;     *-- suppress FORMAT unknown errors;
*-- Graphics initialization ;
*goptions device=win /*target=winprtc */
         ftext=swiss htext=3 pct htitle=3.5 pct lfactor=2;

%*-- Default webhelp location;
%global webhelp;
%let webhelp=http://datavis.ca/sasmac/;

*-- Graphics global variables;
%global gout devtype display;
%let gout=;
%let devtyp=SCREEN;
%let display=ON;


/*****************************************************************/

options notes;
  
